@@ -46,6 +46,7 @@ static gchar *contributors[] = {
 	"Matthias Clasen",
 	"Andrew Clausen",
 	"Jeremy Collins",
+	"Rusty Conover"
 	"Alan Cox",
 	"Mark Crichton",
 	"Andreas Czechanowski",
@@ -64,6 +65,7 @@ static gchar *contributors[] = {
 	"Marc Ewing",
 	N_("Gerg rdi"),
 	"Peter Fales",
+	"Joaquim Fellmann",
 	"Dave Finton",
 	"Milon Firikis",
 	"Raul Perusquia Flores",
