@@ -30,14 +30,16 @@
 extern GlobalConfig global_config;
 extern GList *panel_list;
 
-static GtkWindowClass *foobar_widget_parent_class = NULL;
+extern GtkTooltips *panel_tooltips;
 
 static void foobar_widget_class_init (FoobarWidgetClass *klass);
 static void foobar_widget_init (FoobarWidget *foo);
+static void foobar_widget_realize (GtkWidget *w);
 
 static GtkWidget *das_global_foobar = NULL;
 static GtkWidget *clock_ebox = NULL;
-static GtkTooltips *tooltips = NULL;
+
+static GtkWindowClass *parent_class = NULL;
 
 GtkType
 foobar_widget_get_type (void)
@@ -66,9 +68,11 @@ foobar_widget_get_type (void)
 static void
 foobar_widget_class_init (FoobarWidgetClass *klass)
 {
-	foobar_widget_parent_class = gtk_type_class (FOOBAR_WIDGET_TYPE);
-	tooltips = gtk_tooltips_new ();
-	gtk_tooltips_enable (tooltips);
+	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
+
+        parent_class = gtk_type_class (gtk_window_get_type ());
+
+	widget_class->realize = foobar_widget_realize;
 }
 
 static GtkWidget *
@@ -100,10 +104,23 @@ pixmap_menu_item_new (const char *text, const char *try_file)
 	return item;
 }
 
+static void
+add_tearoff (GtkMenu *menu)
+{
+	GtkWidget *item;
+
+	if (!gnome_preferences_get_menus_have_tearoff ())
+		return;
+	
+	item = gtk_tearoff_menu_item_new ();
+	gtk_widget_show (item);
+	gtk_menu_prepend (menu, item);
+}
+
 static void
 url_show (GtkWidget *w, const char *url)
 {
-	gnome_url_show (url);
+	gnome_url_show (_(url));
 }
 
 static GtkWidget *
@@ -153,25 +170,13 @@ append_gnome_menu (GtkWidget *menu_bar)
 	GtkWidget *menu;
 	int i;
 	char *url[][3] = {
-		{ N_("News (www)"),
-		  "http://gnotices.gnome.org/gnome-news/",
-		  "gnome-news.png" },
-		{ N_("FAQ (www)"),
-		  "http://www.gnome.org/gnomefaq/html/",
-		  GNOME_STOCK_PIXMAP_HELP },
-		{ N_("Mailing Lists (www)"),
-		  "http://www.gnome.org/mailing-lists/archives/",
-		  GNOME_STOCK_PIXMAP_MAIL },
+		{ N_("News (www)"),                N_("http://gnotices.gnome.org/gnome-news/"),          "gnome-news.png" },
+		{ N_("FAQ (www)"),                 N_("http://www.gnome.org/gnomefaq/html/"),            GNOME_STOCK_PIXMAP_HELP },
+		{ N_("Mailing Lists (www)"),       N_("http://mail.gnome.org/mailman/listinfo/"),        GNOME_STOCK_PIXMAP_MAIL },
 		{ NULL, "" },
-		{ N_("Software (www)"),
-		  "http://www.gnome.org/applist/list-martin.phtml",
-		  GNOME_STOCK_PIXMAP_SAVE },
-		{ N_("Development (www)"),
-		  "http://developer.gnome.org/",
-		  "gnome-devel.png" },
-		{ N_("Bug Tracking System (www)"),
-		  "http://bugs.gnome.org/",
-		  "bug-buddy.png" },
+		{ N_("Software (www)"),            N_("http://www.gnome.org/applist/list-martin.phtml"), GNOME_STOCK_PIXMAP_SAVE },
+		{ N_("Development (www)"),         N_("http://developer.gnome.org/"),                    "gnome-devel.png" },
+		{ N_("Bug Tracking System (www)"), N_("http://bugs.gnome.org/"),                         "bug-buddy.png" },
 		{ NULL }
 	};
 	
@@ -190,6 +195,8 @@ append_gnome_menu (GtkWidget *menu_bar)
 	gtk_signal_connect (GTK_OBJECT (item), "activate",
 			    GTK_SIGNAL_FUNC (about_cb), NULL);
 
+	add_tearoff (GTK_MENU (menu));
+
 	item = pixmap_menu_item_new ("", "gnome-spider.png");
 
 	gtk_menu_item_set_submenu (GTK_MENU_ITEM (item), menu);
@@ -230,6 +237,8 @@ append_desktop_menu (GtkWidget *menu_bar)
 	item = gtk_menu_item_new_with_label (_("Arrange Icons"));
 	gtk_menu_item_set_submenu (GTK_MENU_ITEM (item), menu);
 
+	add_tearoff (GTK_MENU (menu));
+
 	menu = gtk_menu_new ();
 
 	gtk_menu_append (GTK_MENU (menu), item);
@@ -258,6 +267,8 @@ append_desktop_menu (GtkWidget *menu_bar)
 			    GTK_SIGNAL_FUNC(panel_quit), 0);
 	setup_internal_applet_drag (item, "LOGOUT:NEW");
 
+	add_tearoff (GTK_MENU (menu));
+
 	item = gtk_menu_item_new_with_label (_(" Desktop "));
 	gtk_menu_item_set_submenu (GTK_MENU_ITEM (item), menu);
 	gtk_menu_bar_append (GTK_MENU_BAR (menu_bar), item);
@@ -326,7 +337,7 @@ timeout_cb (gpointer data)
 	if (das_tm->tm_mday != day) {
 		if (strftime (hour, 20, _("%A %B %d"), das_tm) == 20)
 			hour[19] = '\0';
-		gtk_tooltips_set_tip (tooltips, clock_ebox, hour, NULL);
+		gtk_tooltips_set_tip (panel_tooltips, clock_ebox, hour, NULL);
 
 		day = das_tm->tm_mday;
 	}
@@ -356,7 +367,7 @@ set_fooclock_format (GtkWidget *w, char *format)
 }
 
 static void
-append_format_item (GtkWidget *menu, char *format)
+append_format_item (GtkWidget *menu, const char *format)
 {
 	char hour[20];
 	GtkWidget *item;
@@ -371,7 +382,7 @@ append_format_item (GtkWidget *menu, char *format)
 	gtk_menu_append (GTK_MENU (menu), item);
 	gtk_signal_connect (GTK_OBJECT (item), "activate",
 			    GTK_SIGNAL_FUNC (set_fooclock_format),
-			    format);
+			    (gpointer)format);
 }
 
 static GtkWidget *
@@ -413,10 +424,14 @@ append_clock_menu (GtkWidget *menu_bar)
 	for (i=0; formats[i]; i++)
 		append_format_item (menu2, formats[i]);
 
+	add_tearoff (GTK_MENU (menu2));
+
 	item = gtk_menu_item_new_with_label (_("Format"));
 	gtk_menu_item_set_submenu (GTK_MENU_ITEM (item), menu2);
 	gtk_menu_append (GTK_MENU (menu), item);
-	
+
+	add_tearoff (GTK_MENU (menu));
+
 	item = gtk_menu_item_new ();
 	label = gtk_label_new ("");
 	timeout = gtk_timeout_add (1000, timeout_cb, label);
@@ -455,6 +470,16 @@ foobar_widget_update_winhints (FoobarWidget *foo)
 				   : WIN_LAYER_DOCK);
 }
 
+static void
+foobar_widget_realize (GtkWidget *w)
+{
+	if(GTK_WIDGET_CLASS(parent_class)->realize)
+		GTK_WIDGET_CLASS(parent_class)->realize(w);
+
+	foobar_widget_update_winhints(FOOBAR_WIDGET(w));
+	xstuff_set_no_group(w->window);
+}
+
 static void
 programs_menu_to_display(GtkWidget *menu)
 {
@@ -496,9 +521,6 @@ foobar_widget_init (FoobarWidget *foo)
 
 	gtk_signal_connect (GTK_OBJECT (foo), "delete_event",
 			    GTK_SIGNAL_FUNC (gtk_true), NULL);
-	gtk_signal_connect (GTK_OBJECT (foo), "realize",
-			    GTK_SIGNAL_FUNC (foobar_widget_update_winhints),
-			    NULL);
 
 	gtk_widget_set_usize (GTK_WIDGET (foo),
 			      gdk_screen_width (), -2);
@@ -700,6 +722,8 @@ foobar_widget_redo_window(FoobarWidget *foo)
 	newwin = gdk_window_new(NULL, &attributes, attributes_mask);
 	gdk_window_set_user_data(newwin, window);
 
+	xstuff_set_no_group(newwin);
+
 	/* reparent our main panel window */
 	gdk_window_reparent(foo->ebox->window, newwin, 0, 0);
 	/* reparent all the base event windows as they are also children of
