@@ -22,6 +22,7 @@
 
 #include <config.h>
 #include <gnome.h>
+#include <libgnomeui/gnome-window-icon.h>
 #include <errno.h>
 
 #include "panel-include.h"
@@ -196,10 +197,13 @@ show_run_dialog ()
 	}
 
 	dialog = gnome_dialog_new(_("Run Program"), NULL);
+	gnome_window_icon_set_from_file (GTK_WINDOW (dialog),
+					 GNOME_ICONDIR"/gnome-run.png");
 	gtk_signal_connect(GTK_OBJECT(dialog), "destroy",
 			   GTK_SIGNAL_FUNC(gtk_widget_destroyed),
 			   &dialog);
 	gtk_window_position(GTK_WINDOW(dialog), GTK_WIN_POS_MOUSE);
+	gtk_window_set_wmclass (GTK_WINDOW (dialog), "run_dialog", "Panel");
 	gnome_dialog_append_button_with_pixmap (GNOME_DIALOG (dialog),
 						_("Run"),
 						GNOME_STOCK_PIXMAP_EXEC);
