@@ -584,9 +584,19 @@ panel_destroy(GtkWidget *widget, gpointer data)
 		base_panels--;
 	}
 
+/* don't unref this, since we unref from a signal connected to the
+ * destroy signal of the panel
+ *
+ * Broken, maybe.  1.2 needs to go out, definitely.
+ *
+ * Oh, and null it anyway since we should be done with it.
+ */
+#if 0	
 	if(pd->menu)
-		gtk_widget_destroy(pd->menu);
-	
+		gtk_widget_unref(pd->menu);
+#endif
+	pd->menu = NULL;
+
 	panel_list = g_slist_remove(panel_list,pd);
 	g_free(pd);
 }
@@ -854,7 +864,8 @@ drop_menu(PanelWidget *panel, int pos, char *dir)
 }
 
 static void
-drop_urilist(PanelWidget *panel, int pos, char *urilist)
+drop_urilist(PanelWidget *panel, int pos, char *urilist,
+	     gboolean background_drops)
 {
 	GList *li, *files;
 	struct stat s;
@@ -884,7 +895,8 @@ drop_urilist(PanelWidget *panel, int pos, char *urilist)
 
 		mimetype = gnome_mime_type(filename);
 
-		if(mimetype && !strncmp(mimetype, "image", sizeof("image")-1))
+		if(background_drops &&
+		   mimetype && !strncmp(mimetype, "image", sizeof("image")-1))
 			panel_widget_set_back_pixmap (panel, filename);
 		else if(mimetype &&
 			(strcmp(mimetype, "application/x-gnome-app-info")==0 ||
@@ -979,6 +991,9 @@ is_this_drop_ok(GtkWidget *widget, GdkDragContext *context, guint *info,
 		if(gtk_target_list_find(panel_target_list, 
 					GPOINTER_TO_UINT(li->data),
 					&temp_info)) {
+			if(temp_info == TARGET_COLOR &&
+			   IS_FOOBAR_WIDGET(widget))
+				return FALSE;
 			if(info) *info = temp_info;
 			if(ret_atom) *ret_atom = GPOINTER_TO_UINT(li->data);
 			break;
@@ -1107,7 +1122,8 @@ drag_data_recieved_cb (GtkWidget	 *widget,
 
 	switch (info) {
 	case TARGET_URL:
-		drop_urilist(panel, pos, (char *)selection_data->data);
+		drop_urilist(panel, pos, (char *)selection_data->data,
+			     IS_FOOBAR_WIDGET(widget) ? FALSE : TRUE);
 		break;
 	case TARGET_NETSCAPE_URL:
 		drop_url(panel, pos, (char *)selection_data->data);
@@ -1185,16 +1201,12 @@ basep_pos_connect_signals (BasePWidget *basep)
 					   "align_change",
 					   GTK_SIGNAL_FUNC (update_config_align),
 					   GTK_OBJECT (basep));
-	else if (IS_FLOATING_WIDGET (basep)) {
+	else if (IS_FLOATING_WIDGET (basep))
 		gtk_signal_connect_object (GTK_OBJECT (basep->pos),
 					   "floating_coords_change",
 					   GTK_SIGNAL_FUNC (update_config_floating_pos),
 					   GTK_OBJECT(basep));
-		gtk_signal_connect_object_after (GTK_OBJECT (basep),
-						 "size_allocate",
-						 GTK_SIGNAL_FUNC (update_config_floating_pos_limits),
-						 GTK_OBJECT (basep));
-	} else if (IS_SLIDING_WIDGET (basep)) {
+	else if (IS_SLIDING_WIDGET (basep)) {
 		gtk_signal_connect_object (GTK_OBJECT (basep->pos),
 					   "anchor_change",
 					   GTK_SIGNAL_FUNC (update_config_anchor),
@@ -1203,24 +1215,9 @@ basep_pos_connect_signals (BasePWidget *basep)
 					   "offset_change",
 					   GTK_SIGNAL_FUNC (update_config_offset),
 					   GTK_OBJECT (basep));
-		gtk_signal_connect_object_after (GTK_OBJECT (basep),
-						 "size_allocate",
-						 GTK_SIGNAL_FUNC (update_config_offset_limit),
-						 GTK_OBJECT (basep));
 	}
 }
 
-static void
-floating_size_alloc(BasePWidget *basep, GtkAllocation *alloc, gpointer data)
-{
-	if(!GTK_WIDGET_REALIZED(basep))
-		return;
-
-	gtk_container_foreach(GTK_CONTAINER(basep->panel),
-			      orient_change_foreach,
-			      basep->panel);
-}
-
 static void
 drawer_orient_change_foreach(GtkWidget *w, gpointer data)
 {
@@ -1232,14 +1229,30 @@ drawer_orient_change_foreach(GtkWidget *w, gpointer data)
 }
 
 static void
-sliding_size_alloc(BasePWidget *basep, GtkAllocation *alloc, gpointer data)
+panelw_size_alloc(BasePWidget *basep, GtkAllocation *alloc, gpointer data)
 {
 	if(!GTK_WIDGET_REALIZED(basep))
 		return;
 
-	gtk_container_foreach(GTK_CONTAINER(basep->panel),
-			      drawer_orient_change_foreach,
-			      basep->panel);
+	if(IS_DRAWER_WIDGET(basep)) {
+		gtk_container_foreach(GTK_CONTAINER(basep->panel),
+				      orient_change_foreach,
+				      basep->panel);
+	} else if(IS_FLOATING_WIDGET(basep)) {
+		gtk_container_foreach(GTK_CONTAINER(basep->panel),
+				      orient_change_foreach,
+				      basep->panel);
+		update_config_floating_pos_limits(basep);
+	} else if(IS_ALIGNED_WIDGET(basep)) {
+		gtk_container_foreach(GTK_CONTAINER(basep->panel),
+				      drawer_orient_change_foreach,
+				      basep->panel);
+	} else if(IS_SLIDING_WIDGET(basep)) {
+		gtk_container_foreach(GTK_CONTAINER(basep->panel),
+				      drawer_orient_change_foreach,
+				      basep->panel);
+		update_config_offset_limit(basep);
+	}
 }
 
 void
@@ -1308,6 +1321,10 @@ panel_setup(GtkWidget *panelw)
 				    NULL);
 		basep_pos_connect_signals (basep);
 		basep_widget_disable_buttons(basep);
+
+		gtk_signal_connect_after(GTK_OBJECT(panelw), "size_allocate",
+					 GTK_SIGNAL_FUNC(panelw_size_alloc),
+					 NULL);
 	}
 
 	gtk_signal_connect(GTK_OBJECT(panelw),
@@ -1347,17 +1364,6 @@ panel_setup(GtkWidget *panelw)
 		gtk_signal_connect_after(GTK_OBJECT(panelw), "realize",
 					 GTK_SIGNAL_FUNC(panel_realize),
 					 NULL);
-
-	if(IS_FLOATING_WIDGET(panelw) ||
-	   IS_DRAWER_WIDGET(panelw))
-		gtk_signal_connect_after(GTK_OBJECT(panelw), "size_allocate",
-					 GTK_SIGNAL_FUNC(floating_size_alloc),
-					 NULL);
-	if(IS_SLIDING_WIDGET(panelw) ||
-	   IS_ALIGNED_WIDGET(panelw))
-		gtk_signal_connect_after(GTK_OBJECT(panelw), "size_allocate",
-					 GTK_SIGNAL_FUNC(sliding_size_alloc),
-					 NULL);
 }
 
 /*send state change to all the panels*/
